==> activity-center-api-0.5.2-20170315.061928-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/GuidePageDto.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:GuidePageDto.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.dto<br>
 * Date:2017年3月3日下午2:12:41<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.activity.center.api.dto;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: GuidePageDto <br/>
 * 引导页dto date: 2017年3月3日 下午2:12:41 <br/>
 *
 * @author youhaijun
 * @version
 * @since JDK 1.6
 */
public class GuidePageDto implements Serializable {

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = 7720922780320322944L;

    private Long              id;

    private String            title;

    private Integer           pageType;

    private Long              skinId;

    private Boolean           isDeleted;

    private List<Long>        activityIds;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public List<Long> getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(List<Long> activityIds) {
        this.activityIds = activityIds;
    }

}

==> activity-center-api-0.7.6.2-20170808.094936-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/GuidePageDto.java <==
/**
 * Project Name:activity-center-api<br>
 * File Name:GuidePageDto.java<br>
 * Package Name:cn.com.duiba.tuia.activity.center.api.dto<br>
 * Date:2017年3月3日下午2:12:41<br>
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.activity.center.api.dto;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: GuidePageDto <br/>
 * 引导页dto date: 2017年3月3日 下午2:12:41 <br/>
 *
 * @author youhaijun
 * @version
 * @since JDK 1.6
 */
public class GuidePageDto implements Serializable {

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID = 7720922780320322944L;

    private Long              id;

    private String            title;

    private Integer           pageType;

    private Long              skinId;

    private Boolean           isDeleted;

    private List<Long>        activityIds;

    private List<GuidePageRelationDto> activitys;

    /** 是否默认直投页 */
    private Boolean           isDefault;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public List<Long> getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(List<Long> activityIds) {
        this.activityIds = activityIds;
    }

    public List<GuidePageRelationDto> getActivitys() {
        return activitys;
    }

    public void setActivitys(List<GuidePageRelationDto> activitys) {
        this.activitys = activitys;
    }

    public Boolean getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Boolean isDefault) {
        this.isDefault = isDefault;
    }
}
